#!/usr/bin/python
#
# GUI for RHN Configuration
# Copyright (c) 2000 Red Hat, Inc.
#
# Author: Preston Brown <pbrown@redhat.com>

import os, sys
import string

saveargs = []
for arg in sys.argv[1:]:
    saveargs.append(arg)
    sys.argv.remove(arg)

import gtk
from gtk import TRUE, FALSE
import gnome
import gnome.ui
import libglade
import signal

sys.path.append("/usr/share/rhn/register/")

from translate import _, N_, cat

import config

class Gui:

    def __init__(self,cfg):
        self.xml = libglade.GladeXML("/usr/share/rhn/register/configdlg.glade",
                                     "configDialog", domain="rhn_register")

        self.xml.signal_autoconnect (
            { "onEnableProxyButtonToggled" : self.enableAction,
              "on_enableProxyAuthButton_toggled"  : self.enableAction }            
            )
        self.dlg = self.xml.get_widget("configDialog")
        #self.xml.get_widget("notebook1").remove_page(0)
        self.dlg.connect("delete-event", gtk.mainquit)
        self.dlg.connect("hide", gtk.mainquit)

        self.xml.get_widget("cancelButton").connect("clicked", gtk.mainquit)
        self.xml.get_widget("okButton").connect("clicked", self.finish)
        
        self.cfg = cfg
        try:
            self.cfg.load()
        except:
            dlg = gnome.ui.GnomeErrorDialog(_("There was an error loading your configuration.  Make sure that\nyou have read access to /etc/sysconfig/rhn."),
                                            self.dlg)

        self.setInitialValues()
        self.mainloop()

    def setInitialValues(self):
        # General Tab

        # in case the param doesnt exist, ie, a new user
        if self.cfg.readEntry("enableProxy"):
            proxyValue = self.cfg.readEntry("enableProxy")
        else:
            proxyValue = 0
            
        self.xml.get_widget("enableProxyButton").set_active(proxyValue)
        self.enableAction(self.xml.get_widget("enableProxyButton"))
        self.xml.get_widget("proxyEntry").set_text(self.cfg.readEntry("httpProxy"))

        self.xml.get_widget("enableProxyAuthButton").set_active(self.cfg.readEntry("enableProxyAuth"))
        self.enableAction(self.xml.get_widget("enableProxyAuthButton"))
        self.xml.get_widget("proxyUserEntry").set_text(self.cfg.readEntry("proxyUser"))
        self.xml.get_widget("proxyPasswordEntry").set_text(self.cfg.readEntry("proxyPassword"))
        

    def writeValues(self, button):
        # General
        self.cfg.writeEntry("enableProxy", self.xml.get_widget("enableProxyButton").get_active())
        self.cfg.writeEntry("httpProxy", self.xml.get_widget("proxyEntry").get_text())

        self.cfg.writeEntry("enableProxyAuth", self.xml.get_widget("enableProxyAuthButton").get_active())
        self.cfg.writeEntry("proxyUser", self.xml.get_widget("proxyUserEntry").get_text())
        self.cfg.writeEntry("proxyPassword", self.xml.get_widget("proxyPasswordEntry").get_text())
	
        try:
            self.cfg.save()
        except:
            dlg = gnome.ui.GnomeErrorDialog(_("There was an error saving your configuration.  Make sure that\nyou own %s.") % self.cfg.fileName,
                                            self.dlg)
            return 0

        return 1

    def finish(self, button):
        ret =  self.writeValues(button)
	if ret:
	    self.hide()

    def quit(self):
	while(gtk.events_pending()):
	    gtk.mainiteration()
	gtk.mainquit()

    def hide(self):
        self.dlg.hide()
        while gtk.events_pending():
            gtk.mainiteration(FALSE)
        gtk.mainquit()
        del self

    def mainloop(self):
	gtk.mainloop()
 
    def enableAction(self, button):
        if button.get_name() == "enableProxyButton":
            self.xml.get_widget("proxyEntry").set_sensitive(button.get_active())
            self.xml.get_widget("proxyEntry").grab_focus()
            
        elif button.get_name() == "enableProxyAuthButton":
            self.xml.get_widget("proxyUserEntry").set_sensitive(button.get_active())
            self.xml.get_widget("proxyPasswordEntry").set_sensitive(button.get_active())
            self.xml.get_widget("usernameLabel").set_sensitive(button.get_active())
            self.xml.get_widget("passwordLabel").set_sensitive(button.get_active())



def main():

    gui = Gui()
#    gtk.mainiteration()
    gtk.mainloop()
    return gui

def quit(gui):
    gui.quit()


if __name__ == "__main__":
 main()
